==> trip-0.1.0.tar.gz: trip-0.1.0/util/TcpClientSocket.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const TcpClientSocket_cxx_Version =
    "$Id: TcpClientSocket.cxx,v 1.12 2000/09/20 08:01:34 cvs Exp $";
#ifndef __vxworks


#include <errno.h>
#include <unistd.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdio.h>
#include <sys/socket.h>
#include <strings.h>


#include "VNetworkException.hxx"
#include "TcpClientSocket.hxx"
#include "VEnvVar.hxx"
#include "NetworkAddress.h"
#include "cpLog.h"

TcpClientSocket::TcpClientSocket(const string& hostName,
                                 bool closeCon, bool blocking)
        : _conn(blocking),
        _hostName(hostName),
        _serverPort( -1),
        _closeCon(closeCon),
        _blocking(blocking)
{
    initalize();
}

TcpClientSocket::TcpClientSocket(const string& hostName, int servPort,
                                 bool closeCon, bool blocking)
        : _conn(blocking),
        _hostName(hostName),
        _serverPort(servPort),
        _closeCon(closeCon),
        _blocking(blocking)
{
    initalize();
}

TcpClientSocket::TcpClientSocket(const NetworkAddress& server,
                                 bool closeCon, bool blocking)
        : _conn(blocking),
        _closeCon(closeCon),
        _blocking(blocking)
{
    _hostName = server.getHostName();
    _serverPort = server.getPort();
    cpLog(LOG_ERR, "%s %d", _hostName.c_str(), _serverPort);
    if (_serverPort == -1 )
    {
        _serverPort = VEnvVar::VPS_PORT;
    }
    initalize();
}

TcpClientSocket::TcpClientSocket(const TcpClientSocket& other)
        : _conn(other._blocking)
{
    _conn = other._conn;
}

TcpClientSocket&
TcpClientSocket::operator=(TcpClientSocket& other)
{
    if (this != &other)
    {
        _conn = other._conn;
        _hostName = other._hostName;
        _serverPort = other._serverPort;
        _closeCon = other._closeCon;
        _blocking = other._blocking;
    }
    return *this;
}


void
TcpClientSocket::initalize()
{
    _conn._connId = ::socket(AF_INET, SOCK_STREAM, 0);
    if (_conn._connId == -1)
    {
        char buf[256];
        sprintf(buf, "Failed to connect to fserver %s, reason %s",
                _hostName.c_str(), strerror(errno));
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    bzero(&_conn._connAddr, sizeof(_conn._connAddr));
    _conn._connAddr.sin_family = AF_INET;
    NetworkAddress na(_hostName, _serverPort);
    _conn._connAddr.sin_addr.s_addr = inet_addr(na.getIpName().c_str());
    _conn._connAddr.sin_port = htons(na.getPort());
}

TcpClientSocket::~TcpClientSocket()
{
    close();
}


void
TcpClientSocket::connect() throw (VNetworkException&)
{
    if (::connect(_conn._connId,
                  (SA*)&_conn._connAddr,
                  sizeof(_conn._connAddr)) < 0)
    {
        char buf[256];
        sprintf(buf, "Failed to connect to server %s, reason %s",
                _hostName.c_str(), strerror(errno));
        cpLog(LOG_DEBUG, buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
    _conn.setState();
}

void
TcpClientSocket::close()
{
    if (_closeCon)
        _conn.close();
}

#endif

==> trip-1.0.0.tar.gz: trip-1.0.0/util/TcpClientSocket.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const TcpClientSocket_cxx_Version =
    "$Id: TcpClientSocket.cxx,v 1.16 2001/03/06 00:59:25 cktam Exp $";
#ifndef __vxworks


#include <errno.h>
#include <unistd.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdio.h>
#include <sys/socket.h>
#include <strings.h>


#include "VNetworkException.hxx"
#include "TcpClientSocket.hxx"
#include "VEnvVar.hxx"
#include "NetworkAddress.h"
#include "cpLog.h"

TcpClientSocket::TcpClientSocket(const string& hostName,
                                 bool closeCon, bool blocking)
        : _conn(blocking),
        _hostName(hostName),
        _serverPort( -1),
        _closeCon(closeCon),
        _blocking(blocking)
{
    initalize();
}

TcpClientSocket::TcpClientSocket(const string& hostName, int servPort,
                                 bool closeCon, bool blocking)
        : _conn(blocking),
        _hostName(hostName),
        _serverPort(servPort),
        _closeCon(closeCon),
        _blocking(blocking)
{
    initalize();
}

TcpClientSocket::TcpClientSocket(const NetworkAddress& server,
                                 bool closeCon, bool blocking)
        : _conn(blocking),
        _closeCon(closeCon),
        _blocking(blocking)
{
    _hostName = server.getHostName();
    _serverPort = server.getPort();
    cpLog(LOG_INFO, "%s %d", _hostName.c_str(), _serverPort);
    if (_serverPort == -1 )
    {
        _serverPort = VEnvVar::VPS_PORT;
    }
    initalize();
}

TcpClientSocket::TcpClientSocket(const TcpClientSocket& other)
        : _conn(other._blocking)
{
    _conn = other._conn;
}

TcpClientSocket&
TcpClientSocket::operator=(TcpClientSocket& other)
{
    if (this != &other)
    {
        _conn = other._conn;
        _hostName = other._hostName;
        _serverPort = other._serverPort;
        _closeCon = other._closeCon;
        _blocking = other._blocking;
    }
    return *this;
}


void
TcpClientSocket::initalize()
{
    _conn._connId = ::socket(AF_INET, SOCK_STREAM, 0);
    if (_conn._connId == -1)
    {
        char buf[256];
        sprintf(buf, "Failed to connect to fserver %s, reason %s",
                _hostName.c_str(), strerror(errno));
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    bzero(&_conn._connAddr, sizeof(_conn._connAddr));
    _conn._connAddr.sin_family = AF_INET;
    NetworkAddress na(_hostName, _serverPort);
    _conn._connAddr.sin_addr.s_addr = inet_addr(na.getIpName().c_str());
    _conn._connAddr.sin_port = htons(na.getPort());
}

TcpClientSocket::~TcpClientSocket()
{
    close();
}


void
TcpClientSocket::connect() throw (VNetworkException&)
{
    if (::connect(_conn._connId,
                  (SA*)&_conn._connAddr,
                  sizeof(_conn._connAddr)) < 0)
    {
        char buf[256];
        sprintf(buf, "Failed to connect to server %s, reason %s",
                _hostName.c_str(), strerror(errno));
        cpLog(LOG_DEBUG, buf);
        _conn.close();
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
    _conn.setState();
}

void
TcpClientSocket::close()
{
    if (_closeCon && _conn.getConnId() > 2)
        _conn.close();
}

#endif
